==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/poll.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table cellpadding="2" cellspacing="2" border="0" width="100%" class="picture">
	<tr>
		<td colspan="3" class="bg2">
			<?php echo $i['poll_question'];?><br />
		</td>
	</tr>
	<?php
		unset($voted);
		if (isset($i['options'])) {
		foreach($i['options'] as $p):
	?>
	<tr class="bg4">
		<td>
			<span class="txt_footer">
			<?php echo $p['option_body'];?><br />
			</span>
		</td>
		<td width="50%">
			<table border="0" cellspacing="0" cellpadding="0" width="100%">
				<tr>
					<td width="<?php echo $p['percent'];?>%" class="bg1">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" /><br />
					</td>
					<td width="<?php echo 100-$p['percent'];?>%" class="bg2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" /><br />
					</td>
				</tr>
			</table>
		</td>
		<td>
			<span class="txt_footer">
			<?php echo $p['percent'];?>&#37;<br />
			</span>
		</td>
	</tr>
	<?php 
	endforeach;
	}
	?>
	<tr>
		<td class="bg3" colspan="3" align="right">
			<span class="txt_footer">
			<?php echo $i['total_votes'];?>&nbsp;<?php echo $lang['txt_votes'];?><br />
			</span>
		</td>
	</tr>
</table>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/template/am_default/poll.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table cellpadding="2" cellspacing="2" border="0" width="100%" class="picture">
	<tr>
		<td colspan="3" class="bg2">
			<?php echo $i['poll_question'];?><br />
		</td>
	</tr>
	<?php
		unset($voted);
		if (isset($i['options'])) {
		foreach($i['options'] as $p):
	?>
	<tr class="bg4">
		<td>
			<span class="txt_footer">
			<?php echo $p['option_body'];?><br />
			</span>
		</td>
		<td width="50%">
			<table border="0" cellspacing="0" cellpadding="0" width="100%" class="table_nested">
				<tr>
					<td width="<?php echo $p['percent'];?>%" class="bg1">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" /><br />
					</td>
					<td width="<?php echo 100-$p['percent'];?>%" class="bg2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="7" /><br />
					</td>
				</tr>
			</table>
		</td>
		<td>
			<span class="txt_footer">
			<?php echo $p['percent'];?>&#37;<br />
			</span>
		</td>
	</tr>
	<?php 
	endforeach;
	}
	?>
	<tr>
		<td class="bg3" colspan="3" align="right">
			<span class="txt_footer">
			<?php echo $i['total_votes'];?>&nbsp;<?php echo $lang['txt_votes'];?><br />
			</span>
		</td>
	</tr>
</table>
